package VMOMI::HostCryptoState;
use parent 'VMOMI::SimpleType';

use strict;
use warnings;

1;
